\name{pathWave}
\alias{pathWave}
\title{PathWave analysis tool}
\description{
  Performs an enrichment analysis on optimally arranged grids. Features are generated using a Haar wavelet transform.
}
\usage{
pathWave(x, y, optimalM,  mTest = TRUE, mTestMethod = "Bonferroni", pvalCutoff = 0.01, genes=NULL, diffReac = 5, nperm = 10000, verbose = TRUE)
}
\arguments{
  \item{x}{Matrix of expression values. Names of row elements correspond to elements in optimalM. Columns are data samples.}
  \item{y}{Class factor for x. Should consist of only two classes and length(y) should correspond to ncol(x).}
  \item{optimalM}{List of optimal arranged grids as returned by function pwOptGrids(). See details.}
  \item{mTest}{Should the results be corrected for multiple testing (default TRUE)?}
  \item{mTestMethod}{Method for multiple testing correction (default "Bonferroni") as defined by package multtest.}
  \item{pvalCutoff}{Significance level (default 0.01).}
  \item{genes}{List of genes for each reaction per pathway as returned by pwKEGGxml(). See details.}
  \item{diffReac}{Pathways with how many differentially expressed reaction should be considered (default 5)?}
  \item{nperm}{Number of permutations that should be used to estimate the underlying distribution (default 10,000)?}
  \item{verbose}{Should the progress in permutations be printed after every 100 permutations?}
}
\details{
  \item{x}{Rownames(x) should correspond to the reactionIDs in optimalM as the values of x will be mapped onto the matrices. If for an entry in optimalM no entry in x can be found, it is set to 0.}
  \item{optimalM}{List of the optimal arranged grid for each pathway. The Matrix consists of "0" and the Reaction IDs (see exampoe below). The structure of the list: optimalM$pathwayID$M .}
  \item{genes}{List element "genes" from list returned by pwKEGGXml(). For every pathwayID a vector is stored with the geneIDs. The names of the vector are the reactionIDs. The reactionIDs can occur more than once, if more than one gene is mapped onto the reaction.}
}
\value{
  PathWave returns a list of class PathWave:
  \item{pathwayID}{The ID of enriched pathways.}
  
  In List for each pathwayID
  \item{p.value}{P-value of the enriched pathway. Correspond to the p-value of the highest ranked feature.}
  \item{score}{Size of the feature with which the score was calculated. This is a measurement of the size of the significant pattern.}
  \item{reactions}{Reactions from which the significant features were calculated by a Haar wavelet transform.}
  \item{reaction.p.value}{The p-values of the reactions. Calculated by a t-test on x.}
  \item{reaction.regulation}{The regulation of the reactions: +1 up-regulated, -1 down-regulated, 0 not differentially regulated in class levels(y)[1].}
  \item{feature.p.value}{The p-values of the features.}
  \item{feature}{List of the significant features.}
  
  In List features:
  Each sub-matrix is listed from which the significant features were derived.
}
\references{iChip}
\author{Gunnar Schramm}
\seealso{See Also \code{\link{pwOptGrids}},\code{\link{pwKEGGxml}}}
\examples{
#build test optimal matrices:
test.opM=list()
test.opM[["test1"]]=list(M=matrix(sample(c(paste("test1:R",1:6,sep=""),rep("0",19))),nrow=5))
test.opM[["test2"]]=list(M=matrix(sample(c(paste("test2:R",7:11,sep=""),rep("0",11))),nrow=4))

#generate test class factor for two classes
test.y=as.factor(c(rep("test.1",20),rep("test.2",20)))

#generate test expression matrix with two classes
test.x1=matrix(rnorm(11*length(test.y)),ncol=length(test.y),dimnames=list(paste("test1:R",1:11,sep=""),paste("sample",1:length(test.y),sep="")))
test.x2=matrix(rnorm(11*length(test.y)),ncol=length(test.y),dimnames=list(paste("test2:R",1:11,sep=""),paste("sample",1:length(test.y),sep="")))

#all reactions of the second class are up-regulated in the first pathway
test.x1[,test.y==levels(test.y)[2]]=test.x1[,test.y==levels(test.y)[2]] + 2

test.x=rbind(test.x1,test.x2)


#build gene list
test.gene=list()
test1.genes=as.character(1:6)
test2.genes=as.character(1:5)
names(test1.genes)=paste("test1:R",1:6,sep="")
names(test2.genes)=paste("test2:R",7:11,sep="")
test.gene[["genes"]]=list(test1=test1.genes,test2=test2.genes)

#start pathwave
test.result=pathWave(test.x,test.y,optimalM=test.opM,pvalCutoff=0.05,genes=test.gene$genes,diffReac=1)
}
\keyword{manip}
\keyword{graphs}
\keyword{optimize}